@@ -8,21 +8,19 @@ from django.core.management.base import BaseCommand
 
 
 class Command(BaseCommand):
-    args = '<directory directory ...>'
+    args = '<app>'
     option_list = BaseCommand.option_list + (
-        make_option('--app'),
         make_option('--testclass', default="django.test.TestCase"),
     )
 
-    def handle(self, *directories, **options):
-        app = options.get('app')
-        if app is None:
+    def handle(self, *apps, **options):
+        if not apps:
             sys.stderr.write("""\
-Please specify which app needs its specs generated (use --app=<appname>)
+Please specify at least one app to run specs on.
 """)
             sys.exit(1)
         test_class = options.get('testclass')
-        if not directories:
+        for app in apps:
             directories = [os.path.join(app, "spec")]
-        carinata.main(directories, test_class, os.path.join(app, "tests"))
+            carinata.main(directories, test_class, os.path.join(app, "tests"))
         call_command('test', app)
